# Workbook records
DEFINEDNAME            = 0x0027
FILEVERSION            = 0x0180
WORKBOOK               = 0x0183
WORKBOOK_END           = 0x0184
BOOKVIEWS              = 0x0187
BOOKVIEWS_END          = 0x0188
SHEETS                 = 0x018F
SHEETS_END             = 0x0190
WORKBOOKPR             = 0x0199
SHEET                  = 0x019C
CALCPR                 = 0x019D
WORKBOOKVIEW           = 0x019E
EXTERNALREFERENCES     = 0x02E1
EXTERNALREFERENCES_END = 0x02E2
EXTERNALREFERENCE      = 0x02E3
WEBPUBLISHING          = 0x04A9

# Worksheet records
ROW                       = 0x0000
BLANK                     = 0x0001
NUM                       = 0x0002
BOOLERR                   = 0x0003
BOOL                      = 0x0004
FLOAT                     = 0x0005
STRING                    = 0x0007
FORMULA_STRING            = 0x0008
FORMULA_FLOAT             = 0x0009
FORMULA_BOOL              = 0x000A
FORMULA_BOOLERR           = 0x000B
COL                       = 0x003C
WORKSHEET                 = 0x0181
WORKSHEET_END             = 0x0182
SHEETVIEWS                = 0x0185
SHEETVIEWS_END            = 0x0186
SHEETVIEW                 = 0x0189
SHEETVIEW_END             = 0x018A
SHEETDATA                 = 0x0191
SHEETDATA_END             = 0x0192
SHEETPR                   = 0x0193
DIMENSION                 = 0x0194
SELECTION                 = 0x0198
COLS                      = 0x0386
COLS_END                  = 0x0387
CONDITIONALFORMATTING     = 0x03CD
CONDITIONALFORMATTING_END = 0x03CE
CFRULE                    = 0x03CF
CFRULE_END                = 0x03D0
ICONSET                   = 0x03D1
ICONSET_END               = 0x03D2
DATABAR                   = 0x03D3
DATABAR_END               = 0x03D4
COLORSCALE                = 0x03D5
COLORSCALE_END            = 0x03D6
CFVO                      = 0x03D7
PAGEMARGINS               = 0x03DC
PRINTOPTIONS              = 0x03DD
PAGESETUP                 = 0x03DE
HEADERFOOTER              = 0x03DF
SHEETFORMATPR             = 0x03E5
HYPERLINK                 = 0x03EE
DRAWING                   = 0x04A6
LEGACYDRAWING             = 0x04A7
COLOR                     = 0x04B4
OLEOBJECTS                = 0x04FE
OLEOBJECT                 = 0x04FF
OLEOBJECTS_END            = 0x0580
TABLEPARTS                = 0x0594
TABLEPART                 = 0x0595
TABLEPARTS_END            = 0x0596

# SharedStrings records
SI      = 0x0013
SST     = 0x019F
SST_END = 0x01A0

# Styles records
FONT             = 0x002B
FILL             = 0x002D
BORDER           = 0x002E
XF               = 0x002F
CELLSTYLE        = 0x0030
STYLESHEET       = 0x0296
STYLESHEET_END   = 0x0297
COLORS           = 0x03D9
COLORS_END       = 0x03DA
DXFS             = 0x03F9
DXFS_END         = 0x03FA
TABLESTYLES      = 0x03FC
TABLESTYLES_END  = 0x03FD
FILLS            = 0x04DB
FILLS_END        = 0x04DC
FONTS            = 0x04E3
FONTS_END        = 0x04E4
BORDERS          = 0x04E5
BORDERS_END      = 0x04E6
CELLXFS          = 0x04E9
CELLXFS_END      = 0x04EA
CELLSTYLES       = 0x04EB
CELLSTYLES_END   = 0x04EC
CELLSTYLEXFS     = 0x04F2
CELLSTYLEXFS_END = 0x04F3

# Comment records
COMMENTS        = 0x04F4
COMMENTS_END    = 0x04F5
AUTHORS         = 0x04F6
AUTHORS_END     = 0x04F7
AUTHOR          = 0x04F8
COMMENTLIST     = 0x04F9
COMMENTLIST_END = 0x04FA
COMMENT         = 0x04FB
COMMENT_END     = 0x04FC
TEXT            = 0x04FD

# Table records
AUTOFILTER       = 0x01A1
AUTOFILTER_END   = 0x01A2
FILTERCOLUMN     = 0x01A3
FILTERCOLUMN_END = 0x01A4
FILTERS          = 0x01A5
FILTERS_END      = 0x01A6
FILTER           = 0x01A7
TABLE            = 0x02D7
TABLE_END        = 0x02D8
TABLECOLUMNS     = 0x02D9
TABLECOLUMNS_END = 0x02DA
TABLECOLUMN      = 0x02DB
TABLECOLUMN_END  = 0x02DC
TABLESTYLEINFO   = 0x0481
SORTSTATE        = 0x0492
SORTCONDITION    = 0x0494
SORTSTATE_END    = 0x0495

# QueryTable records
QUERYTABLE            = 0x03BF
QUERYTABLE_END        = 0x03C0
QUERYTABLEREFRESH     = 0x03C1
QUERYTABLEREFRESH_END = 0x03C2
QUERYTABLEFIELDS      = 0x03C7
QUERYTABLEFIELDS_END  = 0x03C8
QUERYTABLEFIELD       = 0x03C9
QUERYTABLEFIELD_END   = 0x03CA

# Connection records
CONNECTIONS     = 0x03AD
CONNECTIONS_END = 0x03AE
CONNECTION      = 0x01C9
CONNECTION_END  = 0x01CA
DBPR            = 0x01CB
DBPR_END        = 0x01CC
